#!/bin/bash
#
# source: http://tuxera.com/opensource/ntfs-3g_ntfsprogs-2012.1.15.tgz
#
# maintainer: gmg (g.monpontet@gmail.com)
#

#------------------ Set Some Variables

soft='ntfs-3g'
softversion='2012.1.15'
packageversion='72.2'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/ntfs-3g_ntfsprogs-$softversion.tgz"
src="$buildir/ntfs-3g_ntfsprogs-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------ Set correct permissions

cd $src
chown -R root:root .
find . \
  \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
  -exec chmod 755 {} \; -o \
  \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
  -exec chmod 644 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --mandir=/usr/man \
  --bindir=/bin \
  --sbindir=/sbin \
  --docdir=/usr/doc/$soft-$softversion \
  --enable-static=no

make -j2
make install DESTDIR=$dest

# Add the HAL fdi file so that automount uses "ntfs-3g" as filesystem type
mkdir -p $dest/usr/share/hal/fdi/policy/10osvendor
cat $buildir/10-ntfs-3g-policy.fdi > $dest/usr/share/hal/fdi/policy/10osvendor/10-ntfs-3g-policy.fdi

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in $(find . -type l) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
)

#------------------- Prepare the documentation

cp -a \
  AUTHORS ChangeLog COPYING* CREDITS INSTALL NEWS README \
  $dest/usr/doc/$soft-$softversion

#------------------- make link default mount.ntfs

cd $dest
ln -sf /bin/ntfs-3g $dest/bin/ntfsmount
ln -sf /bin/ntfs-3g $dest/sbin/mount.ntfs
ln -sf /bin/ntfs-3g $dest/bin/mount.ntfs

#----------------- Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

       |-----handy-ruler-----------------------------------------------------|
ntfs-3g: ntfs-3g (NTFS read-write filesystem driver)
ntfs-3g:
ntfs-3g: The NTFS-3G driver is an open source, freely available NTFS driver
ntfs-3g: for Linux with read and write support.  It provides safe and fast
ntfs-3g: handling of the Windows XP, Windows Server 2003, Windows 2000 and
ntfs-3g: Windows Vista file systems.  Most POSIX file system operations are
ntfs-3g: supported, with the exception of full file ownership and access
ntfs-3g: rights support.
ntfs-3g:
ntfs-3g: Homepage for the ntfs-3g project: http://www.ntfs-3g.org
ntfs-3g:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#------------------ Make the packages and the md5sum

makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5